==> oxine_0.5.orig.tar.gz: oxine-0.5/src/xmllexer.h <==

/*
 * Copyright (C) 2002 the xine project
 *
 * This file is part of xine, a free video player.
 * This file is part of oxine, a free media player.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: xmllexer.h,v 1.3 2005/12/03 17:32:47 mschwerin Exp $
 *
 */

#ifndef XML_LEXER_H
#define XML_LEXER_H

/* public constants */
#define T_ERROR         -1      /* lexer error */
#define T_EOF            0      /* end of file */
#define T_EOL            1      /* end of line */
#define T_SEPAR          2      /* separator ' ' '/t' '\n' '\r' */
#define T_M_START_1      3      /* markup start < */
#define T_M_START_2      4      /* markup start </ */
#define T_M_STOP_1       5      /* markup stop > */
#define T_M_STOP_2       6      /* markup stop /> */
#define T_EQUAL          7      /* = */
#define T_QUOTE          8      /* \" or \' */
#define T_STRING         9      /* "string" */
#define T_IDENT         10      /* identifier */
#define T_DATA          11      /* data */
#define T_C_START       12      /* <!-- */
#define T_C_STOP        13      /* --> */
#define T_TI_START      14      /* <? */
#define T_TI_STOP       15      /* ?> */
#define T_DOCTYPE_START 16      /* <!DOCTYPE */
#define T_DOCTYPE_STOP  17      /* > */


/* public functions */
void lexer_init (char *buf, int size);
int lexer_get_token (char *tok, int tok_size);
char *lexer_decode_entities (char *tok);

#endif

==> oxine_0.6.4.orig.tar.gz: oxine-0.6.4/src/xmllexer.h <==

/*
 * Copyright (C) 2002 the xine project
 *
 * This file is part of xine, a free video player.
 * This file is part of oxine, a free media player.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: xmllexer.h 1182 2006-09-22 07:53:33Z mschwerin $
 *
 */

#ifndef HAVE_XML_LEXER_H
#define HAVE_XML_LEXER_H
#ifdef __cplusplus
extern "C" {
#endif

/* public constants */
#define T_ERROR         -1      /* lexer error */
#define T_EOF            0      /* end of file */
#define T_EOL            1      /* end of line */
#define T_SEPAR          2      /* separator ' ' '/t' '\n' '\r' */
#define T_M_START_1      3      /* markup start < */
#define T_M_START_2      4      /* markup start </ */
#define T_M_STOP_1       5      /* markup stop > */
#define T_M_STOP_2       6      /* markup stop /> */
#define T_EQUAL          7      /* = */
#define T_QUOTE          8      /* \" or \' */
#define T_STRING         9      /* "string" */
#define T_IDENT         10      /* identifier */
#define T_DATA          11      /* data */
#define T_C_START       12      /* <!-- */
#define T_C_STOP        13      /* --> */
#define T_TI_START      14      /* <? */
#define T_TI_STOP       15      /* ?> */
#define T_DOCTYPE_START 16      /* <!DOCTYPE */
#define T_DOCTYPE_STOP  17      /* > */


/* public functions */
void lexer_init (char *buf, int size);
int lexer_get_token (char *tok, int tok_size);
char *lexer_decode_entities (char *tok);

#ifdef __cplusplus
}
#endif
#endif /* HAVE_XML_LEXER_H */
